@@ -20,6 +20,7 @@ class PartsGeneratorWindow
   : public QMainWindow, private Ui::PartsGeneratorWindowForm {
   Q_OBJECT;
 
+  PartsGeneratorWindow(void);
   PartsGeneratorWindow(const PartsGeneratorWindow& rhs);
   PartsGeneratorWindow& operator = (const PartsGeneratorWindow& rhs);
 
@@ -33,11 +34,19 @@ private slots:
   void newFile(void);
   void openFile(void);
   void saveFile(void);
+  bool saveAsFile(void);
   void update(void);
   void outputPixmap(void);
 
+  void fontSizeChangedHandler(int value);
+  void offsetChangedHandler(int value);
+  void fontColorClickedHandler(void);
+  void backgroundColorClickedHandler(void);
+
+  void fontChangedHandler(void);
+
 public:
-  PartsGeneratorWindow(void);
+  PartsGeneratorWindow(const QString& config_file);
   ~PartsGeneratorWindow(void);
 };
 
