@@ -12,11 +12,29 @@
 #include "PartsGeneratorWindow.h"
 
 
+namespace {
+  typedef struct {
+    QString config_file;
+  } options_t;
+};
+
+
+// オプション処理
+static options_t optionHandler(int argc, char *argv[]) {
+
+  options_t options;
+
+  for (int i = 1; i < argc; ++i) {
+    options.config_file = argv[i];
+  }
+
+  return options;
+}
+
+
 //! メイン
 int main(int argc, char *argv[]) {
 
-  // !!! 引数で渡されたフォントがあれば、それを使用する
-
   QApplication app(argc, argv);
 
   // ロケールの適用
@@ -25,8 +43,11 @@ int main(int argc, char *argv[]) {
   translator.load("parts_generator_" + locale);
   app.installTranslator(&translator);
 
+  // オプションの解析
+  const options_t option = optionHandler(argc, argv);
+
   // アプリケーションの起動
-  PartsGeneratorWindow window;
+  PartsGeneratorWindow window(option.config_file);
   window.show();
   return app.exec();
 }
