@@ -18,6 +18,9 @@
   \brief セル用タグ
 */
 class AnimationCellTag {
+
+  AnimationCellTag(void);
+
 public:
   std::string simple_tag;       //!< cell_XXX
   std::string cell_tag;         //!< animation/cell_XXX/cell
@@ -37,6 +40,9 @@ public:
   \brief パターン用タグ
 */
 class AnimationPatternTag {
+
+  AnimationPatternTag(void);
+
 public:
   std::string simple_tag;       //!< pattern_XXX
   std::string pattern_tag;      //!< animation/pattern_XXX/pattern
@@ -60,6 +66,8 @@ public:
   double probability;           //!< 発生確率 / 秒 [1]
   size_t cycle_msec;            //!< 描画周期 [msec]
   std::vector<int> cells;       //!< セルのパターン
+
+  AnimationPattern(void);
 };
 
 #endif /* !ANIMATION_PATTERN_H */
