@@ -6,7 +6,7 @@
 
   $Id$
 
-  \todo シグナルを定義する
+  \todo アニメーションできないならば、disable にする
 */
 
 #include "ClockSettingDialog.h"
@@ -16,12 +16,19 @@ struct ClockSettingDialog::pImpl {
 
   void initializeForm(ClockSettingDialog* parent) {
 
+    // !!! とりあえず、隠しておく
+    parent->no_animation_checkbox_->hide();
+
     // アイコンの適用
     parent->setWindowIcon(QIcon(":icons/qtmclock_icon"));
 
     // 拡大率の変更
     connect(parent->scale_slider_, SIGNAL(valueChanged(int)),
             parent, SLOT(scalingSliderHandler(int)));
+
+    // アニメーション設定の変更
+    connect(parent->no_animation_checkbox_, SIGNAL(clicked(bool)),
+            parent, SLOT(noAnimationCheckboxHandler(bool)));
   }
 };
 
@@ -46,7 +53,19 @@ void ClockSettingDialog::scalingSliderHandler(int value) {
 }
 
 
+void ClockSettingDialog::noAnimationCheckboxHandler(bool checked) {
+
+  emit noAnimationStateChanged(checked);
+}
+
+
 void ClockSettingDialog::setScalingPercent(int value) {
 
   scale_slider_->setValue(value);
 }
+
+
+void ClockSettingDialog::setNoAnimationCheckbox(bool checked) {
+
+  no_animation_checkbox_->setChecked(checked);
+}
