@@ -22,21 +22,29 @@ namespace qrk {
   /*!
     \brief 文字列の SJIS 変換
 
+    コーデック名の指定がなければ、OS 毎に適切なコーデックが使われる
+
     \param text [i] 変換前の文字列
+    \param codec_name [i] コーデック名
 
     \return 変換後の文字列
   */
-  extern const QString toStdStringPath(const QString& text);
+  extern const std::string toStdStringPath(const QString& text,
+                                           const std::string& codec_name = "");
 
 
   /*!
     \brief 文字列の UTF-16 変換
 
+    コーデック名の指定がなければ、OS 毎に適切なコーデックが使われる
+
     \param text [i] 変換前の文字列
+    \param codec_name [i] コーデック名
 
     \return SJIS 変換後の文字列
   */
-  extern const QString fromStdStringPath(const std::string& text);
+  extern const QString toQtStringPath(const std::string& text,
+                                      const std::string& codec_name = "");
 };
 
 #endif /* !TO_SJIS_STRING_H */
