@@ -89,6 +89,11 @@ struct ThemeClockDraw::pImpl {
   }
 
 
+  ~pImpl(void) {
+    delete animation_manager_;
+  }
+
+
   // テーマファイルの読み出し
   bool loadThemeFile(const QString& theme_file, const char* key) {
 
@@ -123,10 +128,32 @@ struct ThemeClockDraw::pImpl {
     theme_loaded_ = true;
     theme_file_ = theme_file;
 
+    themeAdditionalAdjust(theme_file_.toStdString());
+
     return true;
   }
 
 
+  // テーマファイルの追加調整
+  void themeAdditionalAdjust(const std::string& file) {
+
+    // 下位互換性用
+    size_t n = file.size();
+    if (n >= 20) {
+      std::string last_name = file.substr(n - 20, std::string::npos);
+      if (! last_name.compare("lm_clocktheme_02.dat")) {
+        // Rex ちゃん
+        theme_resource_.option["digital/blink"] = "on";
+
+      } else if (! last_name.compare("lm_clocktheme_03.dat")) {
+        // 大空寺あゆ
+        theme_resource_.option["digital/sec"] = "off";
+        theme_resource_.option["digital/blink"] = "on";
+      }
+    }
+  }
+
+
   // リソース名が存在するかを返す
   bool isExist(const char* resource_name,
                const std::vector<std::string>& resources) {
@@ -171,6 +198,7 @@ struct ThemeClockDraw::pImpl {
     loadOption(resource, "digital/sec", tags);
     loadOption(resource, "digital/ampm", tags);
     loadOption(resource, "calendar/month", tags);
+    loadOption(resource, "digital/above", tags);
 
     // デジタル文字を、文字毎に格納
     loadDigitalCharacter(resource, tags, rrda_encoder);
@@ -459,6 +487,10 @@ struct ThemeClockDraw::pImpl {
     // オプション設定の更新
     theme_resource_.option = option;
 
+    // アニメーション情報の読み出し
+    // !!! loadAnimations(theme_resource_, tags, rrda_encoder);
+    // !!!
+
     theme_loaded_ = true;
 
     return true;
@@ -496,9 +528,9 @@ bool ThemeClockDraw::loadThemeFile(const QString& theme_file,
   } else {
     pimpl->animation_manager_ =
       new AnimationManager(pImpl::AnimationCycleMsec, pimpl->patterns_);
-    pimpl->animation_cycle_timer_.start(pImpl::AnimationCycleMsec);
     connect(pimpl->animation_manager_, SIGNAL(updateCell(int)),
             this, SLOT(updateCell(int)));
+    pimpl->animation_cycle_timer_.start(pImpl::AnimationCycleMsec);
   }
 
   return true;
