@@ -30,6 +30,7 @@ static void printHelp(const char* program_name) {
             "\n"
             "options\n"
             "  --help, -h                  print this message.\n"
+            //"  --version, -v               output version infromation.\n"
             "  --theme <file>              Specify the theme file.\n"
             "  --geometry <position>       Place to <position>.\n"
             "\n"
@@ -65,6 +66,12 @@ static options_t optionHandler(int argc, char *argv[]) {
       // 位置指定があれば、指定位置をデフォルト設定は無効にする
       option.position_specified = true;
 
+#if 0
+    } else if ((! strcmp("--version", argv[i])) || (! strcmp("-v", argv[i]))) {
+      printf("qtmclock X.X.X\n");
+      exit(0);
+#endif
+
     } else if ((! strcmp("--help", argv[i])) || (! strcmp("-h", argv[i]))) {
       printHelp(argv[0]);
       exit(1);
