@@ -7,7 +7,7 @@
   $Id$
 */
 
-#include <string>
+#include <stddef.h>
 #include "ReleaseDataFile.h"
 #include "ArchiveConfig.h"
 #include "RrdaDecoder.h"
