@@ -30,6 +30,8 @@
 #include "CellPreviewWidget.h"
 #include "AnimationPattern.h"
 #include "PatternRegisterWidget.h"
+#include "AnimationManager.h"
+#include "SplitString.h"
 
 using namespace qrk;
 
@@ -42,7 +44,11 @@ namespace {
   typedef QMap<std::string, QIcon*> Icons;
   typedef QMap<std::string, QGraphicsItem*> Items;
 
-  typedef QMap<std::string, QRect> AdditionalLinesRect;
+  typedef struct {
+    QRect rect;
+    Qt::PenStyle style;
+  } RectStyle;
+  typedef QMap<std::string, RectStyle> AdditionalLinesRect;
 
   typedef QMap<std::string, QPoint> PositionMap;
 
@@ -92,6 +98,10 @@ static const position_tag_t PositionTags[] = {
 
 struct ThemeConfigWindow::pImpl {
 
+  enum {
+    AnimationCycleMsec = 100,
+  };
+
   QAction* new_act_;
   QAction* open_act_;
   QAction* save_act_;
@@ -129,12 +139,20 @@ struct ThemeConfigWindow::pImpl {
   size_t cell_max_;
   size_t pattern_max_;
   std::vector<PatternRegisterWidget*> pattern_register_;
+  AnimationManager* animation_manager_;
+  std::vector<AnimationPattern> patterns_;
+  QTimer animation_cycle_timer_;
 
   pImpl(void)
     : new_act_(NULL), open_act_(NULL), save_act_(NULL),
       archive_config_(NULL), setting_config_(NULL), save_ok_(false),
       same_hands_center_(false), scene_(NULL), work_dir_("."),
-      cell_max_(0), pattern_max_(0) {
+      cell_max_(0), pattern_max_(0), animation_manager_(NULL) {
+  }
+
+
+  ~pImpl(void) {
+    delete animation_manager_;
   }
 
 
@@ -155,7 +173,6 @@ struct ThemeConfigWindow::pImpl {
     parent->parts_tree_->header()->setResizeMode(1, QHeaderView::Stretch);
 
     // タブの初期選択
-    parent->mode_tab_->setCurrentIndex(0);
     parent->checkbox_tab_->setCurrentIndex(0);
 
     // チェックボックス
@@ -196,13 +213,16 @@ struct ThemeConfigWindow::pImpl {
     connect(parent->image_lineedit_, SIGNAL(returnPressed()),
             parent, SLOT(partsEditHandler()));
     connect(parent->update_button_, SIGNAL(clicked()),
-            parent, SLOT(updateHandlelr()));
+            parent, SLOT(updateHandler()));
 
     // 部品表示ツリー
     connect(parent->parts_tree_, SIGNAL(itemSelectionChanged()),
             parent, SLOT(imageUploadHandler()));
     connect(parent->parts_tree_, SIGNAL(itemClicked(QTreeWidgetItem*, int)),
             parent, SLOT(updateAnimationItems(QTreeWidgetItem*, int)));
+    connect(parent->parts_tree_,
+            SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)),
+            parent, SLOT(updateImageHandler(QTreeWidgetItem*, int)));
 
     // リリース
     connect(&release_dialog_, SIGNAL(release(QString, QString)),
@@ -220,6 +240,14 @@ struct ThemeConfigWindow::pImpl {
     // 時刻オフセット
     connect(parent->offset_slider_, SIGNAL(valueChanged(int)),
             parent, SLOT(offsetUpdated(int)));
+
+    // アニメーション用パターンの追加
+    connect(parent->add_pattern_button_, SIGNAL(clicked()),
+            parent, SLOT(addPatternHandler()));
+
+    // アニメーションの再生用
+    connect(&animation_cycle_timer_, SIGNAL(timeout()),
+            parent, SLOT(evaluateAnimation()));
   }
 
 
@@ -436,8 +464,6 @@ struct ThemeConfigWindow::pImpl {
   // 読み出し
   void load(ThemeConfigWindow* parent) {
 
-    // !!! cell_max_, pattern_max_ をどこかで初期化すべき
-
     // 設定を読み出して反映する
     loadSettings(parent);
 
@@ -480,6 +506,11 @@ struct ThemeConfigWindow::pImpl {
     bool ampm = ! setting_config_->getValue("digital/ampm").compare("on");
     parent->show_ampm_checkbox_->setChecked(ampm);
 
+    // デジタル表示を手前に 表示 / 非表示
+    bool digital_above =
+      ! setting_config_->getValue("digital/above").compare("on");
+    parent->digital_above_checkbox_->setChecked(digital_above);
+
     // アニメーション情報の読み出し
     loadAnimations();
 
@@ -564,19 +595,28 @@ struct ThemeConfigWindow::pImpl {
       AnimationPatternMax = 1000,   // アニメーション用パターンの最大数
     };
 
-    // アニメーション用の画像を読み出す
+    // アニメーション情報の初期化
     QTreeWidgetItem* animation_item = name_to_item_["animation"];
+    for (size_t i = 0; i < (cell_max_ + 1); ++i) {
+      // ツリーのセル情報を削除
+      delete animation_item->child(0);
+    }
+    for (size_t i = 0; i < pattern_max_; ++i) {
+      // 現在のパターンを削除
+      delete pattern_register_[i];
+    }
+    cell_max_ = 0;
+    pattern_max_ = 0;
+    patterns_.clear();
+
+    // アニメーション用の画像を読み出す
     for (size_t i = 0; i < AnimationCellMax; ++i) {
-      // 順番に評価して、見つからなければ、終了
-      AnimationCellTag cell_tags(i);
 
       // アニメーション登録用のツリーを追加
-      QTreeWidgetItem* cell_item = new QTreeWidgetItem(animation_item);
-      cell_item->setText(0, cell_tags.simple_tag.c_str());
-      cell_item->setCheckState(0, Qt::Unchecked);
-      registerTreeItem(cell_tags.cell_tag, cell_item);
-
+      AnimationCellTag cell_tags(i);
+      addAnimationNode(animation_item, cell_tags);
       if (! loadImage(cell_tags.cell_tag.c_str())) {
+        // 順番に評価して、見つからなければ、終了
         break;
       }
       cell_max_ = i + 1;
@@ -606,6 +646,17 @@ struct ThemeConfigWindow::pImpl {
   }
 
 
+  // アニメーションノードの追加
+  void addAnimationNode(QTreeWidgetItem* animation_item,
+                        AnimationCellTag& cell_tags) {
+
+    QTreeWidgetItem* cell_item = new QTreeWidgetItem(animation_item);
+    cell_item->setText(0, cell_tags.simple_tag.c_str());
+    //cell_item->setCheckState(0, Qt::Unchecked);
+    registerTreeItem(cell_tags.cell_tag, cell_item);
+  }
+
+
   // アニメーション情報の保存
   void saveAnimations(void) {
 
@@ -628,43 +679,54 @@ struct ThemeConfigWindow::pImpl {
   // アニメーションパターン登録用のウィジットを配置
   void loadAnimationPatterns(ThemeConfigWindow* parent) {
 
-    QWidget* widget_parent = parent->mode_tab_->widget(1);
-
     pattern_register_.clear();
     for (size_t i = 0; i < pattern_max_; ++i) {
-
-      PatternRegisterWidget* widget = new PatternRegisterWidget(widget_parent);
-      connect(widget, SIGNAL(probabilityChanged(int, double)),
-              parent, SLOT(probabilityChangedHandler(int, double)));
-      connect(widget, SIGNAL(cycleChanged(int, int)),
-              parent, SLOT(cycleChangedHandler(int, int)));
-      connect(widget, SIGNAL(patternChanged(int, const std::string&)),
-              parent, SLOT(patternChangedHandler(int, const std::string&)));
-
-      // 設定パターンを反映
-      AnimationPatternTag pattern_tags(i);
-      widget->setName(pattern_tags.simple_tag, i);
-
-      double probability =
-        atof(setting_config_->getValue(pattern_tags.probability_tag).c_str());
-      widget->setProbability(probability);
-
-      size_t cycle =
-        atoi(setting_config_->getValue(pattern_tags.cycle_tag).c_str());
-      widget->setCycle(cycle);
-
-      widget->setPattern(setting_config_->getValue(pattern_tags.pattern_tag));
-
-      parent->patterns_layout_->addWidget(widget);
-      pattern_register_.push_back(widget);
+      addAnimationPattern(i, parent);
     }
   }
 
 
-  // アニメーションパターンの保存
-  void saveAnimationPatterns(ThemeConfigWindow* parent) {
+  // パターンの登録
+  void addAnimationPattern(size_t index, ThemeConfigWindow* parent) {
 
-    // !!!
+    QWidget* widget_parent = parent->mode_tab_->widget(1);
+    PatternRegisterWidget* widget = new PatternRegisterWidget(widget_parent);
+    connect(widget, SIGNAL(probabilityChanged(int, double)),
+            parent, SLOT(probabilityChangedHandler(int, double)));
+    connect(widget, SIGNAL(cycleChanged(int, int)),
+            parent, SLOT(cycleChangedHandler(int, int)));
+    connect(widget, SIGNAL(patternChanged(int, const std::string&)),
+            parent, SLOT(patternChangedHandler(int, const std::string&)));
+
+    // 設定パターンを反映
+    AnimationPatternTag pattern_tags(index);
+    widget->setName(pattern_tags.simple_tag, index);
+
+    double probability =
+      atof(setting_config_->getValue(pattern_tags.probability_tag).c_str());
+    widget->setProbability(probability);
+
+    size_t cycle_msec =
+      atoi(setting_config_->getValue(pattern_tags.cycle_tag).c_str());
+    widget->setCycle(cycle_msec);
+
+    std::string tags = setting_config_->getValue(pattern_tags.pattern_tag);
+    widget->setPattern(tags);
+
+    parent->patterns_layout_->addWidget(widget);
+    pattern_register_.push_back(widget);
+
+    // パターン情報の登録
+    AnimationPattern animation;
+    animation.probability = probability;
+    animation.cycle_msec = cycle_msec;
+
+    std::vector<std::string> tokens;
+    size_t n = qrk::split(tokens, tags, ", \t");
+    for (size_t j = 0; j < n; ++j) {
+      animation.cells.push_back(atoi(tokens[j].c_str()));
+    }
+    patterns_.push_back(animation);
   }
 
 
@@ -773,14 +835,15 @@ struct ThemeConfigWindow::pImpl {
       AnimationCellTag cell_tags(i);
 
       if ((! current_tag_.compare("animation")) ||
-          (name_to_item_[cell_tags.cell_tag]->checkState(0) == Qt::Checked)) {
+          (name_to_item_[cell_tags.cell_tag]->checkState(0) == Qt::Checked) ||
+          (! current_tag_.compare(cell_tags.cell_tag))) {
         registerItem(parent, cell_tags.cell_tag.c_str());
       }
     }
 
     // カレンダー部品
-    registerItem(parent, "calendar/m1", "C0");
-    registerItem(parent, "calendar/m2", "C1");
+    registerItem(parent, "calendar/m1", "C1");
+    registerItem(parent, "calendar/m2", "C2");
     registerItem(parent, "calendar/d1", "C2");
     registerItem(parent, "calendar/d2", "C3");
     registerItem(parent, "calendar/we", "MON");
@@ -801,7 +864,10 @@ struct ThemeConfigWindow::pImpl {
     if (! setting_config_->getValue("digital/colon").compare("on")) {
       registerItem(parent, "digital/cl", ":");
     }
-    registerItem(parent, "digital/ap", "A");
+
+    if (setting_config_->getValue("digital/ampm").compare("off")) {
+      registerItem(parent, "digital/ap", "A");
+    }
 
     // アナログ部品
     QGraphicsItem* short_hand = registerItem(parent, "analog/hari_h");
@@ -818,21 +884,21 @@ struct ThemeConfigWindow::pImpl {
     // 追加部品
     registerItem(parent, "additional/near");
 
-    // 補助線
+    // 線
     QPen rect_pen;
-    rect_pen.setStyle(Qt::DashLine);
-
     QPen line_pen;
     line_pen.setStyle(Qt::DotLine);
 
     for (AdditionalLinesRect::iterator it = additional_lines_rect_.begin();
          it != additional_lines_rect_.end(); ++it) {
 
+      rect_pen.setStyle(it.value().style);
+
       // 枠線を描画
       std::string key = it.key();
       QGraphicsItem* item_parent = items_[key];
 
-      QRect rect = it.value();
+      QRect rect = it.value().rect;
       QGraphicsRectItem* rect_item =
         new QGraphicsRectItem(0, 0, rect.width() - 1, rect.height() - 1,
                               item_parent);
@@ -1020,12 +1086,22 @@ struct ThemeConfigWindow::pImpl {
   bool findItemTag(const char* tags[],
                    size_t n, const std::string& tag) {
 
+    // 通常のアイテム
     for (size_t i = 0; i < n; ++i) {
-
       if (! tag.compare(tags[i])) {
         return true;
       }
     }
+
+    // アニメーション画像のアイテム
+    // +1 枚分のセルも登録可能にする
+    for (size_t i = 0; i < (cell_max_ + 1); ++i) {
+      AnimationCellTag cell_tags(i);
+      if (! tag.compare(cell_tags.cell_tag)) {
+        return true;
+      }
+    }
+
     return false;
   }
 
@@ -1220,6 +1296,15 @@ struct ThemeConfigWindow::pImpl {
       fileName.toStdString().substr(dir_length, std::string::npos);
     archive_config_->setNormalData(archive_tag, set_name);
 
+    // 最後のアニメーションセルに登録された場合、もう１ノード追加する
+    AnimationCellTag cell_tags(cell_max_);
+    if (! current_tag_.compare(cell_tags.cell_tag)) {
+      ++cell_max_;
+      QTreeWidgetItem* animation_item = name_to_item_["animation"];
+      AnimationCellTag cell_tags(cell_max_);
+      addAnimationNode(animation_item, cell_tags);
+    }
+
     loadImage(current_tag_.c_str());
     updateItems();
     setSaveEnabled(parent, true);
@@ -1274,12 +1359,16 @@ struct ThemeConfigWindow::pImpl {
                   parent->blink_checkbox_->isChecked() ? "on" : "off");
     option.insert("digital/ampm",
                   parent->show_ampm_checkbox_->isChecked() ? "on" : "off");
+    option.insert("digital/above",
+                  parent->digital_above_checkbox_->isChecked() ? "on" : "off");
     option.insert("calendar/month",
                   parent->month_checkbox_->isChecked() ? "on" : "off");
 
-    preview_draw_.loadThemeResource(pixmaps_, offset ,
-                                    digital_positions, calendar_positions,
-                                    option);
+    // アニメーション情報の登録
+    setAnimations(offset, parent);
+
+    preview_draw_.loadThemeResource(pixmaps_, offset , digital_positions,
+                                    calendar_positions, option);
     setPreviewEnabled(parent, true);
 
     // ダイアログの表示
@@ -1295,6 +1384,27 @@ struct ThemeConfigWindow::pImpl {
   }
 
 
+  // アニメーション情報の登録
+  void setAnimations(QMap<std::string, QRect>& offset,
+                     ThemeConfigWindow* parent) {
+
+    // セル情報の登録
+    for (size_t i = 0; i < cell_max_; ++i) {
+      AnimationCellTag cell_tags(i);
+      setOffset(offset, cell_tags.cell_tag);
+    }
+
+    // Animation Manager の初期化
+    if (! animation_manager_) {
+      animation_manager_ =
+        new AnimationManager(pImpl::AnimationCycleMsec, patterns_);
+      connect(animation_manager_, SIGNAL(updateCell(int)),
+              parent, SLOT(updateCell(int)));
+      animation_cycle_timer_.start(pImpl::AnimationCycleMsec);
+    }
+  }
+
+
   // Preview の終了
   void previewClosed(ThemeConfigWindow* parent) {
 
@@ -1304,6 +1414,11 @@ struct ThemeConfigWindow::pImpl {
     // ボタンアイコンの変更
     QIcon stop_icon(":/icons/play_icon");
     parent->play_button_->setIcon(stop_icon);
+
+    // Animation Manager の削除
+    animation_cycle_timer_.stop();
+    delete animation_manager_;
+    animation_manager_ = NULL;
   }
 
 
@@ -1319,20 +1434,24 @@ struct ThemeConfigWindow::pImpl {
 
 
   // プレビューの再描画
-  void redrawPreview(ThemeConfigWindow* parent) {
+  void redrawPreview(ThemeConfigWindow* parent,
+                     int cell_index = ClockPartsDraw::InvalidCellIndex) {
 
     int sec_offset = parent->offset_slider_->value() * 60;
-    preview_draw_.redraw(sec_offset);
+    preview_draw_.redraw(sec_offset, NULL, cell_index);
   }
 
 
   // 補助線の追加
-  void drawAdditionalLine(const std::string& selected_tag) {
+  void drawAdditionalLine(const std::string& selected_tag,
+                          Qt::PenStyle pen_style = Qt::DashLine) {
 
+#if 0
     // ベース画像は対象外
     if (! selected_tag.compare("base/base_org")) {
       return;
     }
+#endif
 
     // 関連部品についても描画を行う
     if (! selected_tag.compare("analog")) {
@@ -1377,6 +1496,12 @@ struct ThemeConfigWindow::pImpl {
     } else if (! selected_tag.compare("calendar/d1")) {
       drawAdditionalLine("calendar/d2");
       drawAdditionalLine("calendar/s2");
+
+    } else if (! selected_tag.compare("animation")) {
+      for (size_t i = 0; i < cell_max_; ++i) {
+        AnimationCellTag cell_tags(i);
+        drawAdditionalLine(cell_tags.cell_tag);
+      }
     }
 
     // 曜日を移動させるための調整
@@ -1385,7 +1510,6 @@ struct ThemeConfigWindow::pImpl {
       drawAdditionalLine("calendar/we");
     }
 
-
     PositionMap::iterator it_position = parts_positions_.find(selected_tag);
     if (it_position == parts_positions_.end()) {
       return;
@@ -1417,9 +1541,11 @@ struct ThemeConfigWindow::pImpl {
     }
 
     // 描画する枠線を登録
-    additional_lines_rect_.
-      insert(selected_tag,
-             (QRect(position.x(), position.y(), size.width(), size.height())));
+    RectStyle rect_style;
+    rect_style.rect = QRect(position.x(), position.y(),
+                            size.width(), size.height());
+    rect_style.style = pen_style;
+    additional_lines_rect_.insert(selected_tag, rect_style);
   }
 
 
@@ -1562,8 +1688,7 @@ void ThemeConfigWindow::closeEvent(QCloseEvent* event) {
 void ThemeConfigWindow::newFile(void) {
 
   // プレビューを閉じる
-  pimpl->
-preview_draw_.close();
+  pimpl->preview_draw_.close();
 
   // 空の名前でファイル読み出しを指示し、設定が空のオブジェクトを作成する
   pimpl->loadArchiveFile(this, "");
@@ -1706,22 +1831,25 @@ void ThemeConfigWindow::aboutApplication(void) {
 // 描画アイテムの更新
 void ThemeConfigWindow::updateAnimationItems(QTreeWidgetItem* item,
                                              int column) {
-  static_cast<void>(column);
+  if (column != 0) {
+    return;
+  }
 
   std::string name = pimpl->item_to_name_[item];
   if (! name.compare(0, strlen("animation/cell_"), "animation/cell_")) {
 
-    // 指定セルが、チェックされていなければ、チェックは変更しない
-    if (item->checkState(0) != Qt::Checked) {
-      return;
-    }
-
-    for (size_t i = 0; i < pimpl->cell_max_; ++i) {
-      // 指定セル以外は閉じる
-      AnimationCellTag cell_tags(i);
-      QTreeWidgetItem* compare_item = pimpl->name_to_item_[cell_tags.cell_tag];
-      if (compare_item != item) {
-        compare_item->setCheckState(0, Qt::Unchecked);
+    // 指定セルがチェックされていなければ、チェックは変更しない
+    if (item->checkState(0) == Qt::Checked) {
+      for (size_t i = 0; i < (pimpl->cell_max_ + 1); ++i) {
+        // 指定セル以外は閉じる
+        AnimationCellTag cell_tags(i);
+        QTreeWidgetItem* compare_item =
+          pimpl->name_to_item_[cell_tags.cell_tag];
+        if (compare_item != item) {
+          compare_item->setCheckState(0, Qt::Unchecked);
+        } else {
+          pimpl->current_tag_ = cell_tags.cell_tag;
+        }
       }
     }
     pimpl->updateItems();
@@ -1729,6 +1857,25 @@ void ThemeConfigWindow::updateAnimationItems(QTreeWidgetItem* item,
 }
 
 
+// ダブルクリックで、画像を配置
+void ThemeConfigWindow::updateImageHandler(QTreeWidgetItem* item, int column) {
+
+  if (column != 1) {
+    return;
+  }
+
+  // 画像のタグだったら、ファイルの配置ダイアログを開く
+  std::string name = pimpl->item_to_name_[item];
+
+  size_t n = sizeof(ImageTags) / sizeof(ImageTags[0]);
+  bool found = pimpl->findItemTag(ImageTags, n, name);
+  if (found) {
+    updateHandler();
+  }
+}
+
+
+
 // 針の中心を、揃えるか、の設定
 void ThemeConfigWindow::centerCheckHandler(bool checked) {
 
@@ -1823,6 +1970,7 @@ void ThemeConfigWindow::imageUploadHandler(void) {
 
   // 補助線の再描画
   pimpl->removeAdditionalLine();
+  pimpl->drawAdditionalLine("base/base_org", Qt::SolidLine);
   pimpl->drawAdditionalLine(pimpl->current_tag_);
   pimpl->updateItems();
 
@@ -1874,7 +2022,7 @@ void ThemeConfigWindow::partsEditHandler(void) {
 
 
 // 部品画像の更新、選択
-void ThemeConfigWindow::updateHandlelr(void) {
+void ThemeConfigWindow::updateHandler(void) {
 
   QString fileName =
     QFileDialog::getOpenFileName(this, tr("Open parts file."),
@@ -1949,6 +2097,11 @@ void ThemeConfigWindow::probabilityChangedHandler(int index,
   pimpl->setting_config_->
     setValue(pattern_tags.probability_tag, probability_str);
 
+  // プレビュー用の情報も更新
+  if (static_cast<int>(pimpl->patterns_.size()) > index) {
+    pimpl->patterns_[index].probability = probability;
+  }
+
   // 保存可能にする
   pimpl->setSaveEnabled(this, true);
 }
@@ -1964,6 +2117,11 @@ void ThemeConfigWindow::cycleChangedHandler(int index, int cycle_msec) {
   pimpl->setting_config_->
     setValue(pattern_tags.cycle_tag, cycle_msec_str);
 
+  // プレビュー用の情報も更新
+  if (static_cast<int>(pimpl->patterns_.size()) > index) {
+    pimpl->patterns_[index].cycle_msec = cycle_msec;
+  }
+
   // 保存可能にする
   pimpl->setSaveEnabled(this, true);
 }
@@ -1977,6 +2135,40 @@ void ThemeConfigWindow::patternChangedHandler(int index,
   pimpl->setting_config_->
     setValue(pattern_tags.pattern_tag, pattern);
 
+  // プレビュー用の情報も更新
+  if (static_cast<int>(pimpl->patterns_.size()) > index) {
+    pimpl->patterns_[index].cells.clear();
+
+    // !!! くくる
+    std::vector<std::string> tokens;
+    size_t n = qrk::split(tokens, pattern, ", \t");
+    for (size_t j = 0; j < n; ++j) {
+      pimpl->patterns_[index].cells.push_back(atoi(tokens[j].c_str()));
+    }
+  }
+
   // 保存可能にする
   pimpl->setSaveEnabled(this, true);
 }
+
+
+// パターンの追加
+void ThemeConfigWindow::addPatternHandler(void) {
+
+  pimpl->addAnimationPattern(pimpl->pattern_max_, this);
+}
+
+
+// 表示セルの更新
+void ThemeConfigWindow::updateCell(int index) {
+
+  pimpl->redrawPreview(this, index);
+}
+
+
+void ThemeConfigWindow::evaluateAnimation(void) {
+
+  if (pimpl->animation_manager_) {
+    pimpl->animation_manager_->evaluate();
+  }
+}
