@@ -1,6 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="ja_JP">
-<defaultcodec></defaultcodec>
 <context>
     <name>PatternRegisterWidgetForm</name>
     <message>
@@ -78,107 +77,107 @@
         <translation>Theme Config</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="311"/>
+        <location filename="ThemeConfigWindowForm.ui" line="317"/>
         <source>long hand</source>
         <translation>長針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="288"/>
+        <location filename="ThemeConfigWindowForm.ui" line="294"/>
         <source>base</source>
         <translation>ベース</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="303"/>
+        <location filename="ThemeConfigWindowForm.ui" line="309"/>
         <source>short hand</source>
         <translation>短針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="319"/>
+        <location filename="ThemeConfigWindowForm.ui" line="325"/>
         <source>second hand</source>
         <translation>秒針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="328"/>
+        <location filename="ThemeConfigWindowForm.ui" line="334"/>
         <source>digital character</source>
         <translation>デジタル文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="628"/>
+        <location filename="ThemeConfigWindowForm.ui" line="664"/>
         <source>toolbar</source>
         <translation>ツールバー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="335"/>
+        <location filename="ThemeConfigWindowForm.ui" line="341"/>
         <source>hour</source>
         <translation>時</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="359"/>
+        <location filename="ThemeConfigWindowForm.ui" line="365"/>
         <source>minute</source>
         <translation>分</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="375"/>
+        <location filename="ThemeConfigWindowForm.ui" line="381"/>
         <source>second</source>
         <translation>秒</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="391"/>
+        <location filename="ThemeConfigWindowForm.ui" line="397"/>
         <source>AM/PM</source>
         <translation>AM/PM</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="351"/>
+        <location filename="ThemeConfigWindowForm.ui" line="357"/>
         <source>colon</source>
         <translation>コロン</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="278"/>
+        <location filename="ThemeConfigWindowForm.ui" line="284"/>
         <source>Node</source>
         <translation>項目</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="283"/>
+        <location filename="ThemeConfigWindowForm.ui" line="289"/>
         <source>Value</source>
         <translation>画像</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="646"/>
+        <location filename="ThemeConfigWindowForm.ui" line="682"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1481"/>
+        <location filename="ThemeConfigWindow.cpp" line="1617"/>
         <source>Create a new config file.</source>
         <translation>設定ファイルの新規作成.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="658"/>
+        <location filename="ThemeConfigWindowForm.ui" line="694"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1485"/>
+        <location filename="ThemeConfigWindow.cpp" line="1621"/>
         <source>Open an exist config file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="670"/>
+        <location filename="ThemeConfigWindowForm.ui" line="706"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1489"/>
+        <location filename="ThemeConfigWindow.cpp" line="1625"/>
         <source>Save the config file to disk.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="146"/>
+        <location filename="ThemeConfigWindowForm.ui" line="152"/>
         <source>hands&apos;s center are samve.</source>
         <translation>長針、短針、秒針の中心を揃える.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="296"/>
+        <location filename="ThemeConfigWindowForm.ui" line="302"/>
         <source>analog parts</source>
         <translation>アナログ部品</translation>
     </message>
@@ -188,279 +187,284 @@
         <translation>再生 / 停止</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="581"/>
+        <location filename="ThemeConfigWindowForm.ui" line="617"/>
         <source>File (&amp;F)</source>
         <translation>ファイル (&amp;F)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="594"/>
+        <location filename="ThemeConfigWindowForm.ui" line="630"/>
         <source>Edit (&amp;E)</source>
         <translation>編集 (&amp;E)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="600"/>
+        <location filename="ThemeConfigWindowForm.ui" line="636"/>
         <source>Help (&amp;H)</source>
         <translation>ヘルプ (&amp;H)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1480"/>
+        <location filename="ThemeConfigWindow.cpp" line="1616"/>
         <source>New</source>
         <translation>新規作成</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1484"/>
+        <location filename="ThemeConfigWindow.cpp" line="1620"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1488"/>
+        <location filename="ThemeConfigWindow.cpp" line="1624"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="675"/>
+        <location filename="ThemeConfigWindowForm.ui" line="711"/>
         <source>Release (&amp;R)</source>
         <translation>リリース (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="680"/>
+        <location filename="ThemeConfigWindowForm.ui" line="716"/>
         <source>Exit (&amp;Q)</source>
         <translation>終了 (&amp;Q)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="683"/>
+        <location filename="ThemeConfigWindowForm.ui" line="719"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="688"/>
+        <location filename="ThemeConfigWindowForm.ui" line="724"/>
         <source>Save as</source>
         <translation>名前を付けて保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="693"/>
+        <location filename="ThemeConfigWindowForm.ui" line="729"/>
         <source>Preview (&amp;R)</source>
         <translation>プレビュー (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="696"/>
+        <location filename="ThemeConfigWindowForm.ui" line="732"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="701"/>
+        <location filename="ThemeConfigWindowForm.ui" line="737"/>
         <source>About (&amp;A)</source>
         <translation>このアプリケーションについて (&amp;A)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="342"/>
+        <location filename="ThemeConfigWindowForm.ui" line="348"/>
         <source>h2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="366"/>
+        <location filename="ThemeConfigWindowForm.ui" line="372"/>
         <source>m2</source>
         <translation>位置 (100 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="382"/>
+        <location filename="ThemeConfigWindowForm.ui" line="388"/>
         <source>s2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="197"/>
+        <location filename="ThemeConfigWindowForm.ui" line="203"/>
         <source>blink digital colon.</source>
         <translation>デジタル文字のコロンを点滅させる.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="207"/>
+        <location filename="ThemeConfigWindowForm.ui" line="213"/>
         <source>show digital second.</source>
         <translation>デジタル文字の秒を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1567"/>
+        <location filename="ThemeConfigWindow.cpp" line="1702"/>
         <source>Open archive list file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1609"/>
+        <location filename="ThemeConfigWindow.cpp" line="1744"/>
         <source>archive list (*.txt)</source>
         <translation>設定ファイル (*.txt)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1607"/>
+        <location filename="ThemeConfigWindow.cpp" line="1742"/>
         <source>Save archive list file.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="643"/>
+        <location filename="ThemeConfigWindowForm.ui" line="679"/>
         <source>New (&amp;N)</source>
         <translation>新規作成 (&amp;N)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="655"/>
+        <location filename="ThemeConfigWindowForm.ui" line="691"/>
         <source>Open (&amp;O)</source>
         <translation>開く (&amp;O)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="667"/>
+        <location filename="ThemeConfigWindowForm.ui" line="703"/>
         <source>Save (&amp;S)</source>
         <translation>保存 (&amp;S)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="509"/>
+        <location filename="ThemeConfigWindowForm.ui" line="515"/>
         <source>Parts image</source>
         <translation>部品画像の更新</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="519"/>
+        <location filename="ThemeConfigWindowForm.ui" line="525"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="156"/>
+        <location filename="ThemeConfigWindowForm.ui" line="162"/>
         <source>show analog second.</source>
         <translation>秒針を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1852"/>
+        <location filename="ThemeConfigWindow.cpp" line="2028"/>
         <source>Open parts file.</source>
         <translation>部品ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1854"/>
+        <location filename="ThemeConfigWindow.cpp" line="2030"/>
         <source>parts file (*.png)</source>
         <translation>部品ファイル (*.png)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1688"/>
+        <location filename="ThemeConfigWindow.cpp" line="1823"/>
         <source>About qtmclock_config</source>
         <translation>qtmclock_config について</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1692"/>
+        <location filename="ThemeConfigWindow.cpp" line="1827"/>
         <source>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Theme making tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
         <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="126"/>
+        <location filename="ThemeConfigWindowForm.ui" line="132"/>
         <source>Analog Clock</source>
         <translation>アナログ時計</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="184"/>
+        <location filename="ThemeConfigWindowForm.ui" line="190"/>
         <source>Clock Settings</source>
         <translation>描画設定</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="243"/>
+        <location filename="ThemeConfigWindowForm.ui" line="249"/>
         <source>Calendar</source>
         <translation>カレンダー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="249"/>
+        <location filename="ThemeConfigWindowForm.ui" line="255"/>
         <source>Calendar Settings</source>
         <translation>描画設定</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="400"/>
+        <location filename="ThemeConfigWindowForm.ui" line="406"/>
         <source>calendar</source>
         <translation>カレンダー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="414"/>
+        <location filename="ThemeConfigWindowForm.ui" line="420"/>
         <source>month</source>
         <translation>月</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="438"/>
+        <location filename="ThemeConfigWindowForm.ui" line="444"/>
         <source>day</source>
         <translation>日</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="471"/>
+        <location filename="ThemeConfigWindowForm.ui" line="477"/>
         <source>day of the week</source>
         <translation>曜日</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="258"/>
+        <location filename="ThemeConfigWindowForm.ui" line="264"/>
         <source>show month.</source>
         <translation>月を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="407"/>
+        <location filename="ThemeConfigWindowForm.ui" line="413"/>
         <source>number</source>
         <translation>数値</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="429"/>
+        <location filename="ThemeConfigWindowForm.ui" line="435"/>
         <source>month_separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="445"/>
+        <location filename="ThemeConfigWindowForm.ui" line="451"/>
         <source>c_d2</source>
         <translation>位置 (1 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="453"/>
+        <location filename="ThemeConfigWindowForm.ui" line="459"/>
         <source>day_separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="463"/>
+        <location filename="ThemeConfigWindowForm.ui" line="469"/>
         <source>separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="421"/>
+        <location filename="ThemeConfigWindowForm.ui" line="427"/>
         <source>c_m2</source>
         <translation>位置 (1 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="480"/>
+        <location filename="ThemeConfigWindowForm.ui" line="486"/>
         <source>additional</source>
         <translation>追加部品</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="487"/>
+        <location filename="ThemeConfigWindowForm.ui" line="493"/>
         <source>near</source>
         <translation>手前</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="101"/>
+        <location filename="ThemeConfigWindowForm.ui" line="107"/>
         <source>Placement</source>
         <translation>配置</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="496"/>
+        <location filename="ThemeConfigWindowForm.ui" line="502"/>
         <source>animation</source>
         <translation>アニメーション</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="539"/>
+        <location filename="ThemeConfigWindowForm.ui" line="545"/>
         <source>Animation</source>
         <translation>アニメーション</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="190"/>
+        <location filename="ThemeConfigWindowForm.ui" line="196"/>
         <source>show digital colon.</source>
         <translation>デジタル文字のコロンを表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="178"/>
+        <location filename="ThemeConfigWindowForm.ui" line="184"/>
         <source>Digital Clock</source>
         <translation>デジタル時計</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="217"/>
+        <location filename="ThemeConfigWindowForm.ui" line="223"/>
         <source>show AM/PM.</source>
         <translation>AM / PM を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="224"/>
+        <location filename="ThemeConfigWindowForm.ui" line="230"/>
         <source>show digital above analog hands.</source>
         <translation>デジタル表示をアナログ針よりも手前に表示する.</translation>
     </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="577"/>
+        <source>Add Pattern</source>
+        <translation>パターンの追加</translation>
+    </message>
 </context>
 </TS>
